[Python-checkins] cpython (3.3): Issue #15392: Do not run tests if threading/_thread not available. Otherwise

terry.reedy python-checkins at python.org
Wed May 29 04:22:54 CEST 2013


http://hg.python.org/cpython/rev/968f6094788b
changeset:   83969:968f6094788b
branch:      3.3
parent:      83966:75432fb6b9af
user:        Terry Jan Reedy <tjreedy at udel.edu>
date:        Tue May 28 22:21:53 2013 -0400
summary:
  Issue #15392: Do not run tests if threading/_thread not available. Otherwise
touchup test_idle. Rename README.txt.

files:
  Lib/idlelib/idle_test/@README.txt |   0 
  Lib/test/test_idle.py             |  16 ++++++++--------
  2 files changed, 8 insertions(+), 8 deletions(-)


diff --git a/Lib/idlelib/idle_test/@README.txt b/Lib/idlelib/idle_test/README.txt
rename from Lib/idlelib/idle_test/@README.txt
rename to Lib/idlelib/idle_test/README.txt
diff --git a/Lib/test/test_idle.py b/Lib/test/test_idle.py
--- a/Lib/test/test_idle.py
+++ b/Lib/test/test_idle.py
@@ -1,13 +1,13 @@
 # Skip test if tkinter wasn't built or idlelib was deleted.
 from test.support import import_module
-import_module('tkinter')  # discard return
-itdir = import_module('idlelib.idle_test')
+import_module('tkinter')
+import_module('threading')  # imported by PyShell, imports _thread
+idletest = import_module('idlelib.idle_test')
 
-# Without test_main present, regrtest.runtest_inner (line1219)
-# imitates unittest.main by calling
-# unittest.TestLoader().loadTestsFromModule(this_module)
-# which look for load_tests and uses it if found.
-load_tests = itdir.load_tests
+# Without test_main present, regrtest.runtest_inner (line1219) calls
+# unittest.TestLoader().loadTestsFromModule(this_module) which calls
+# load_tests() if it finds it. (Unittest.main does the same.)
+load_tests = idletest.load_tests
 
 if __name__ == '__main__':
     import unittest
@@ -1,13 +1,13 @@
-# Skip test if tkinter wasn't built or idlelib was deleted.
+# Skip test if _tkinter or _thread wasn't built or idlelib was deleted.
 from test.support import import_module

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list